==> 0.0.54.tar.gz: lib/widgets/certificate_visualizer.dart <==
import 'dart:io';

import 'package:flutter_firebase_basic_tools/logic/check_if_user_is_admin.dart';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter_firebase_basic_tools/logic/localStorageManager/local_storage_manager.dart';
import 'package:flutter_firebase_basic_tools/logic/generate_certificate_html_from_values.dart';
import 'package:flutter_firebase_basic_tools/logic/timestamp_to_date.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:easy_web_view/easy_web_view.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:path_provider/path_provider.dart';

class CertificatesVisualizer extends StatefulWidget {
  const CertificatesVisualizer({
    @required this.id,
    @required this.uid,
    @required this.userName,
    @required this.courseName,
    @required this.date,
  });

  final String id;
  final String uid;
  final String userName;
  final String courseName;
  final String date;

  @override
  _CertificatesVisualizerState createState() => _CertificatesVisualizerState();
}

class _CertificatesVisualizerState extends State<CertificatesVisualizer> {
  TextEditingController certificateIDInputController = TextEditingController();
  String htmlCertificate = "";
  bool isWaitingPdfBase64 = false;
  bool userIsAdmin = false;

  String otherCourseName = "";
  String otherDate = "";
  String otherUserID = "";
  String otherUserName = "";

  String attributesForUser = "";
  String attributesForAdmin = "";
  bool attributesAreForAdmin = false;

  getHtmlCertificate() async {
    htmlCertificate = await HtmlCertificateFromValues().generate(
      courseName: widget.courseName,
      userName: widget.userName,
      date: widget.date,
      id: widget.id,
    );

    setState(() {});
  }

  downloadCertificate(http.Response response) async {
    String base64PDF = response.body.toString();

    attributesForUser =
        "/certificate_${widget.userName.split(" ").join("_")}_${widget.courseName.split(" ").join("_")}_${widget.id}.pdf";
    attributesForAdmin =
        "/certificate_${otherUserName.split(" ").join("_")}_${otherCourseName.split(" ").join("_")}_${certificateIDInputController.text}.pdf";

    attributesAreForAdmin =
        userIsAdmin && certificateIDInputController.text != "";

    LocalStorageManager.save(
      base64PDF,
      attributesAreForAdmin ? attributesForAdmin : attributesForUser,
    );

    isWaitingPdfBase64 = false;
    setState(() {});
  }

  checkIfIsAdmin() async {
    userIsAdmin = await checkIfUserIsAdmin(widget.uid);
    setState(() {});
  }

  generateCertificate() async {
    String urlForUser =
        'https://us-central1-abei-21f7c.cloudfunctions.net/createPDF?userName=${widget.userName}&courseName=${widget.courseName}&date=${widget.date}&certificateID=${widget.id}';
    String urlForAdmin =
        'https://us-central1-abei-21f7c.cloudfunctions.net/createPDF?userName=$otherUserName&courseName=$otherCourseName&date=$otherDate&certificateID=${certificateIDInputController.text}';

    await http.get(
      userIsAdmin && certificateIDInputController.text != ""
          ? urlForAdmin
          : urlForUser,
      headers: {
        "Access-Control-Allow-Origin": "*",
      },
    ).then((response) => {downloadCertificate(response)});
  }

  getOtherCertificateInfo() async {
    await FirebaseFirestore.instance
        .collection("certificates")
        .doc(certificateIDInputController.text)
        .get()
        .then((DocumentSnapshot certificateDoc) async {
      otherDate = TimestampToDate().convert(certificateDoc.data()["date"]);
      otherUserID = certificateDoc.data()["user_id"];

      await FirebaseFirestore.instance
          .collection("courses")
          .doc(certificateDoc.data()["course_id"])
          .get()
          .then((DocumentSnapshot courseDoc) async {
        otherCourseName = courseDoc.data()["name"];

        await FirebaseFirestore.instance
            .collection("users")
            .doc(otherUserID)
            .get()
            .then((DocumentSnapshot userDoc) async {
          otherUserName =
              userDoc.data()["firstname"] + " " + userDoc.data()["lastname"];
          generateCertificate();
          return null;
        });

        return null;
      });
      return null;
    });
  }

  @override
  void initState() {
    super.initState();
    getHtmlCertificate();
    checkIfIsAdmin();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: htmlCertificate != "" && !isWaitingPdfBase64
          ? Row(
              children: [
                Spacer(flex: 1),
                Expanded(
                  flex: 50,
                  child: Container(
                    height: MediaQuery.of(context).size.height,
                    width: MediaQuery.of(context).size.width,
                    color: Colors.grey,
                    child: FractionallySizedBox(
                      heightFactor: 0.95,
                      widthFactor: 0.8,
                      child: EasyWebView(
                        src: htmlCertificate,
                        isHtml: true,
                        isMarkdown: false,
                        convertToWidgets: false,
                        onLoaded: () {},
                      ),
                    ),
                  ),
                ),
                Spacer(flex: 1),
                Expanded(
                  flex: 5,
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      RaisedButton(
                        onPressed: () async {
                          isWaitingPdfBase64 = true;
                          setState(() {});

                          if (userIsAdmin &&
                              certificateIDInputController.text != "") {
                            getOtherCertificateInfo();
                          } else {
                            generateCertificate();
                          }
                        },
                        child: Text(
                          "Download",
                        ),
                      ),
                      RaisedButton(
                        onPressed: () async {},
                        child: Text(
                          "Send via email",
                        ),
                      ),
                      userIsAdmin
                          ? TextFormField(
                              decoration: InputDecoration(
                                labelText: "Other certificate ID",
                              ),
                              controller: certificateIDInputController,
                            )
                          : Container(),
                    ],
                  ),
                ),
                Spacer(flex: 1),
              ],
            )
          : Center(
              child: CircularProgressIndicator(
                valueColor: new AlwaysStoppedAnimation<Color>(
                  CustomColors().lightAqua,
                ),
              ),
            ),
    );
  }
}

==> 0.0.56.tar.gz: lib/widgets/certificate_visualizer.dart <==
import 'dart:convert';
import 'package:flutter_firebase_basic_tools/logic/check_if_user_is_admin.dart';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter_firebase_basic_tools/logic/localStorageManager/local_storage_manager.dart';
import 'package:flutter_firebase_basic_tools/logic/generate_certificate_html_from_values.dart';
import 'package:flutter_firebase_basic_tools/logic/timestamp_to_date.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:flutter_firebase_basic_tools/logic/my_flutter_app_icons.dart'
    as custicon;
import 'package:universal_platform/universal_platform.dart';
import 'package:webview_flutter/webview_flutter.dart';

class CertificatesVisualizer extends StatefulWidget {
  const CertificatesVisualizer({
    @required this.id,
    @required this.uid,
    @required this.userName,
    @required this.courseName,
    @required this.date,
  });

  final String id;
  final String uid;
  final String userName;
  final String courseName;
  final String date;

  @override
  _CertificatesVisualizerState createState() => _CertificatesVisualizerState();
}

class _CertificatesVisualizerState extends State<CertificatesVisualizer> {
  TextEditingController certificateIDInputController = TextEditingController();
  String htmlCertificate = "";
  bool isWaitingPdfBase64 = false;
  bool userIsAdmin = false;

  String otherCourseName = "";
  String otherDate = "";
  String otherUserID = "";
  String otherUserName = "";

  String attributesForUser = "";
  String attributesForAdmin = "";
  bool attributesAreForAdmin = false;

  getHtmlCertificate() async {
    htmlCertificate = await HtmlCertificateFromValues().generate(
      courseName: widget.courseName,
      userName: widget.userName,
      date: widget.date,
      id: widget.id,
    );

    setState(() {});
  }

  downloadCertificate(http.Response response) async {
    String base64PDF = response.body.toString();

    attributesForUser =
        "/certificate_${widget.userName.split(" ").join("_")}_${widget.courseName.split(" ").join("_")}_${widget.id}.pdf";
    attributesForAdmin =
        "/certificate_${otherUserName.split(" ").join("_")}_${otherCourseName.split(" ").join("_")}_${certificateIDInputController.text}.pdf";

    LocalStorageManager.save(
      base64PDF,
      attributesAreForAdmin ? attributesForAdmin : attributesForUser,
    );

    isWaitingPdfBase64 = false;
    setState(() {});
  }

  checkIfIsAdmin() async {
    userIsAdmin = await checkIfUserIsAdmin(widget.uid);
    setState(() {});
  }

  generateCertificate() async {
    String urlForUser =
        'https://us-central1-abei-21f7c.cloudfunctions.net/createPDF?userName=${widget.userName}&courseName=${widget.courseName}&date=${widget.date}&certificateID=${widget.id}';
    String urlForAdmin =
        'https://us-central1-abei-21f7c.cloudfunctions.net/createPDF?userName=$otherUserName&courseName=$otherCourseName&date=$otherDate&certificateID=${certificateIDInputController.text}';

    attributesAreForAdmin =
        userIsAdmin && certificateIDInputController.text != "";

    await http.get(
      attributesAreForAdmin ? urlForAdmin : urlForUser,
      headers: {
        "Access-Control-Allow-Origin": "*",
      },
    ).then((response) => {downloadCertificate(response)});
  }

  getOtherCertificateInfo() async {
    await FirebaseFirestore.instance
        .collection("certificates")
        .doc(certificateIDInputController.text)
        .get()
        .then((DocumentSnapshot certificateDoc) async {
      otherDate = TimestampToDate().convert(certificateDoc.data()["date"]);
      otherUserID = certificateDoc.data()["user_id"];

      await FirebaseFirestore.instance
          .collection("courses")
          .doc(certificateDoc.data()["course_id"])
          .get()
          .then((DocumentSnapshot courseDoc) async {
        otherCourseName = courseDoc.data()["name"];

        await FirebaseFirestore.instance
            .collection("users")
            .doc(otherUserID)
            .get()
            .then((DocumentSnapshot userDoc) async {
          otherUserName =
              userDoc.data()["firstname"] + " " + userDoc.data()["lastname"];
          generateCertificate();
          return null;
        });

        return null;
      });
      return null;
    });
  }

  @override
  void initState() {
    super.initState();
    getHtmlCertificate();
    checkIfIsAdmin();
  }

  loadHtml(WebViewController controller, BuildContext context) async {
    final String contentBase64 =
        base64Encode(const Utf8Encoder().convert(htmlCertificate));
    await controller.loadUrl('data:text/html;base64,$contentBase64');
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: htmlCertificate != "" && !isWaitingPdfBase64
          ? Column(
              children: [
                Spacer(flex: 1),
                Expanded(
                  flex: 1,
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      IconButton(
                        icon: Icon(UniversalPlatform.isWeb
                            ? Icons.download_outlined
                            : Icons.share),
                        onPressed: () async {
                          isWaitingPdfBase64 = true;
                          setState(() {});

                          if (userIsAdmin &&
                              certificateIDInputController.text != "") {
                            getOtherCertificateInfo();
                          } else {
                            generateCertificate();
                          }
                        },
                      ),
                      userIsAdmin
                          ? TextFormField(
                              decoration: InputDecoration(
                                labelText: "Other certificate ID",
                              ),
                              controller: certificateIDInputController,
                            )
                          : Container(),
                    ],
                  ),
                ),
                Expanded(
                  flex: 28,
                  child: WebView(
                    onWebViewCreated: (WebViewController webViewController) {
                      loadHtml(webViewController, context);
                    },
                  ),
                ),
                Spacer(flex: 1),
              ],
            )
          : Center(
              child: CircularProgressIndicator(
                valueColor: new AlwaysStoppedAnimation<Color>(
                  CustomColors().lightAqua,
                ),
              ),
            ),
    );
  }
}
